@@ -16,27 +16,29 @@ class Form496Part3ItemBase(CampaignContributionBase):
     On Schedule A, campaign filers are required to itemize monetary
     contributions received during the period covered by the filing.
     """
+
     amount = models.DecimalField(
-        verbose_name='amount',
+        verbose_name="amount",
         decimal_places=2,
         max_digits=14,
         help_text="Amount received from the contributor in the period covered "
-                  "by the filing (from RCPT_CD.AMOUNT)"
+        "by the filing (from RCPT_CD.AMOUNT)",
     )
     interest_rate = models.CharField(
-        verbose_name='interest rate',
+        verbose_name="interest rate",
         max_length=30,
         blank=True,
-        help_text='Interest rate of a loan. This is sometimes expressed as a '
-                  'decimal (e.g., 0.10) and other times as a percent (e.g., '
-                  '10.0% (from RCPT_CD.INT_RATE)'
+        help_text="Interest rate of a loan. This is sometimes expressed as a "
+        "decimal (e.g., 0.10) and other times as a percent (e.g., "
+        "10.0% (from RCPT_CD.INT_RATE)",
     )
 
     class Meta:
         """
         Model options.
         """
-        app_label = 'calaccess_processed_filings'
+
+        app_label = "calaccess_processed_filings"
         abstract = True
 
 
@@ -44,60 +46,70 @@ class Form496Part3Item(Form496Part3ItemBase):
     """
     Monetary contributions of greater than $100 from the Form 496's Part 3.
     """
+
     filing = models.ForeignKey(
-        'Form496Filing',
-        related_name='part3_items',
+        "Form496Filing",
+        related_name="part3_items",
         null=True,
         on_delete=models.SET_NULL,
-        help_text='Foreign key referring to the Form 496 on which the monetary'
-                  ' contribution was reported (from RCPT_CD.FILING_ID)',
+        help_text="Foreign key referring to the Form 496 on which the monetary"
+        " contribution was reported (from RCPT_CD.FILING_ID)",
     )
 
     class Meta:
         """
         Model options.
         """
-        app_label = 'calaccess_processed_filings'
-        unique_together = ((
-            'filing',
-            'line_item',
-        ),)
+
+        app_label = "calaccess_processed_filings"
+        unique_together = (
+            (
+                "filing",
+                "line_item",
+            ),
+        )
         verbose_name = "Form 496 (Late Independent Expenditure) Part 3 item"
 
     def __str__(self):
-        return '%s-%s' % (self.filing, self.line_item)
+        return "%s-%s" % (self.filing, self.line_item)
 
 
 class Form496Part3ItemVersion(Form496Part3ItemBase):
     """
     Every version of monetary contributions of greater than $100 from the Form 496's Part 3.
     """
+
     filing_version = models.ForeignKey(
-        'Form496FilingVersion',
-        related_name='part3_items',
+        "Form496FilingVersion",
+        related_name="part3_items",
         null=True,
         on_delete=models.SET_NULL,
-        help_text='Foreign key referring to the version of the Form 496 that includes the received contribution'
+        help_text="Foreign key referring to the version of the Form 496 that includes the received contribution",
     )
 
     class Meta:
         """
         Model options.
         """
-        app_label = 'calaccess_processed_filings'
-        unique_together = ((
-            'filing_version',
-            'line_item',
-        ),)
-        index_together = ((
-            'filing_version',
-            'line_item',
-        ),)
+
+        app_label = "calaccess_processed_filings"
+        unique_together = (
+            (
+                "filing_version",
+                "line_item",
+            ),
+        )
+        index_together = (
+            (
+                "filing_version",
+                "line_item",
+            ),
+        )
         verbose_name = "Form 496 (Late Independent Expenditure) Part 3 item version"
 
     def __str__(self):
-        return '%s-%s-%s' % (
+        return "%s-%s-%s" % (
             self.filing_version.filing_id,
             self.filing_version.amend_id,
-            self.line_item
+            self.line_item,
         )
